# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/tarot/users.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tarot/tarot/users.proto\x12\x05tarot\"\xa6\x01\n\x0cTelegramUser\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\x12\x15\n\rlanguage_code\x18\x06 \x01(\t\x12\x0e\n\x06is_bot\x18\x07 \x01(\x08\x12\x12\n\nis_premium\x18\x08 \x01(\x08\x12\x16\n\x0eprofile_photos\x18\t \x03(\t\"\xb0\x01\n\rSpreadProfile\x12\r\n\x05tg_id\x18\x01 \x01(\x05\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\x12\n\nbirth_date\x18\x03 \x01(\t\x12\x12\n\nbirth_time\x18\x04 \x01(\t\x12\x13\n\x0b\x62irth_place\x18\x05 \x01(\t\x12\x13\n\x0bzodiac_sign\x18\x06 \x01(\t\x12\x1b\n\x13\x63hinese_zodiac_sign\x18\x07 \x01(\t\x12\x0e\n\x06gender\x18\x08 \x01(\t\"!\n\x13TelegramUserRequest\x12\n\n\x02id\x18\x02 \x01(\x05\x32\x8e\x02\n\x05Users\x12>\n\x12\x43reateTelegramUser\x12\x13.tarot.TelegramUser\x1a\x13.tarot.TelegramUser\x12\x42\n\x0fGetTelegramUser\x12\x1a.tarot.TelegramUserRequest\x1a\x13.tarot.TelegramUser\x12>\n\x12UpdateTelegramUser\x12\x13.tarot.TelegramUser\x1a\x13.tarot.TelegramUser\x12\x41\n\x13UpdateSpreadProfile\x12\x14.tarot.SpreadProfile\x1a\x14.tarot.SpreadProfileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.tarot.users_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TELEGRAMUSER']._serialized_start=35
  _globals['_TELEGRAMUSER']._serialized_end=201
  _globals['_SPREADPROFILE']._serialized_start=204
  _globals['_SPREADPROFILE']._serialized_end=380
  _globals['_TELEGRAMUSERREQUEST']._serialized_start=382
  _globals['_TELEGRAMUSERREQUEST']._serialized_end=415
  _globals['_USERS']._serialized_start=418
  _globals['_USERS']._serialized_end=688
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from tarot.tarot import users_pb2 as tarot_dot_tarot_dot_users__pb2


class UsersStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTelegramUser = channel.unary_unary(
                '/tarot.Users/CreateTelegramUser',
                request_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
                response_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.GetTelegramUser = channel.unary_unary(
                '/tarot.Users/GetTelegramUser',
                request_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUserRequest.SerializeToString,
                response_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.UpdateTelegramUser = channel.unary_unary(
                '/tarot.Users/UpdateTelegramUser',
                request_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
                response_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.UpdateSpreadProfile = channel.unary_unary(
                '/tarot.Users/UpdateSpreadProfile',
                request_serializer=tarot_dot_tarot_dot_users__pb2.SpreadProfile.SerializeToString,
                response_deserializer=tarot_dot_tarot_dot_users__pb2.SpreadProfile.FromString,
                )


class UsersServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSpreadProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UsersServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTelegramUser,
                    request_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                    response_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'GetTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTelegramUser,
                    request_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUserRequest.FromString,
                    response_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'UpdateTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTelegramUser,
                    request_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                    response_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'UpdateSpreadProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSpreadProfile,
                    request_deserializer=tarot_dot_tarot_dot_users__pb2.SpreadProfile.FromString,
                    response_serializer=tarot_dot_tarot_dot_users__pb2.SpreadProfile.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tarot.Users', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Users(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/CreateTelegramUser',
            tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/GetTelegramUser',
            tarot_dot_tarot_dot_users__pb2.TelegramUserRequest.SerializeToString,
            tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/UpdateTelegramUser',
            tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSpreadProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/UpdateSpreadProfile',
            tarot_dot_tarot_dot_users__pb2.SpreadProfile.SerializeToString,
            tarot_dot_tarot_dot_users__pb2.SpreadProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TelegramUser(_message.Message):
    __slots__ = ["id", "username", "first_name", "last_name", "language_code", "is_bot", "is_premium", "profile_photos"]
    ID_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    IS_BOT_FIELD_NUMBER: _ClassVar[int]
    IS_PREMIUM_FIELD_NUMBER: _ClassVar[int]
    PROFILE_PHOTOS_FIELD_NUMBER: _ClassVar[int]
    id: int
    username: str
    first_name: str
    last_name: str
    language_code: str
    is_bot: bool
    is_premium: bool
    profile_photos: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[int] = ..., username: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., language_code: _Optional[str] = ..., is_bot: bool = ..., is_premium: bool = ..., profile_photos: _Optional[_Iterable[str]] = ...) -> None: ...

class SpreadProfile(_message.Message):
    __slots__ = ["tg_id", "full_name", "birth_date", "birth_time", "birth_place", "zodiac_sign", "chinese_zodiac_sign", "gender"]
    TG_ID_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    BIRTH_DATE_FIELD_NUMBER: _ClassVar[int]
    BIRTH_TIME_FIELD_NUMBER: _ClassVar[int]
    BIRTH_PLACE_FIELD_NUMBER: _ClassVar[int]
    ZODIAC_SIGN_FIELD_NUMBER: _ClassVar[int]
    CHINESE_ZODIAC_SIGN_FIELD_NUMBER: _ClassVar[int]
    GENDER_FIELD_NUMBER: _ClassVar[int]
    tg_id: int
    full_name: str
    birth_date: str
    birth_time: str
    birth_place: str
    zodiac_sign: str
    chinese_zodiac_sign: str
    gender: str
    def __init__(self, tg_id: _Optional[int] = ..., full_name: _Optional[str] = ..., birth_date: _Optional[str] = ..., birth_time: _Optional[str] = ..., birth_place: _Optional[str] = ..., zodiac_sign: _Optional[str] = ..., chinese_zodiac_sign: _Optional[str] = ..., gender: _Optional[str] = ...) -> None: ...

class TelegramUserRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...
